@@ -461,7 +461,7 @@ void SVC_RemoteCommand( netadr_t from, msg_t *msg ) {
 
 	// TTimo - https://zerowing.idsoftware.com/bugzilla/show_bug.cgi?id=534
 	time = Com_Milliseconds();
-	if (time<(lasttime+500)) {
+	if ( (unsigned)( time - lasttime ) < 500u ) {
 		return;
 	}
 	lasttime = time;
